==> haskell-chell-0.5-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.5
id: chell-0.5-K0NTHQ8usQxTXu9tz1mAD
key: chell-0.5-K0NTHQ8usQxTXu9tz1mAD
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: 2dd50289babbba4b02e1d55c186f1239
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-0.5
hs-libraries: HSchell-0.5-K0NTHQ8usQxTXu9tz1mAD
depends:
    ansi-terminal-0.9.1-DB3Zf3I0Zem5oqZIKoyRWZ base-4.12.0.0
    bytestring-0.10.8.2 options-1.2.1.1-FMpEp48m7Zu8qqR2BW81vr
    patience-0.2.1.1-Ac4ITT3UjP43CS8LmqYmVB
    random-1.1-3ypV4EIycgb35PKjTYYr5q template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.5-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.5
id: chell-0.5-4V1q6UzVnjaFXi7XtZNXMR
key: chell-0.5-4V1q6UzVnjaFXi7XtZNXMR
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: fc10391e717af6909b2fbd8718a1b0ad
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-0.5
hs-libraries: HSchell-0.5-4V1q6UzVnjaFXi7XtZNXMR
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    bytestring-0.10.8.2 options-1.2.1.1-FMpEp48m7Zu8qqR2BW81vr
    patience-0.2.1.1-Ac4ITT3UjP43CS8LmqYmVB
    random-1.1-3ypV4EIycgb35PKjTYYr5q template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
